@@ -1,7 +1,7 @@
 from discord.ext import commands
 from .constants import ALL_GAMES
 
-class Games(commands.Cog, *ALL_GAMES):
+class Games(*ALL_GAMES):
     """
     This category provides awesome games like tictactoe, madlib and hangman!
     """
@@ -9,4 +9,4 @@ class Games(commands.Cog, *ALL_GAMES):
         super().__init__(bot)
 
 def setup(bot: commands.Bot):
-    bot.add_cog(Games(bot))
\ No newline at end of file
+    bot.add_cog(Games(bot))
