@@ -1,8 +1,7 @@
 import discord
 from discord.ext import commands
 
-
-class Hangman:
+class Hangman(commands.Cog):
     """
     Hang man command
     """
@@ -29,7 +28,7 @@ class Hangman:
 
     @commands.command("hangman", aliases=["hm"])
     async def command(self, ctx: commands.Context):  # sourcery no-metrics
-        word = "hello" # TODO: add more words
+        word = "hello"
         word = list(word)
         guesses = []
         errors = 0
@@ -124,4 +123,4 @@ class Hangman:
             else:
                 await ctx.send(
                     f"Invalid Syntax: {message.content.lower()} is not a letter"
-                )
+                )
\ No newline at end of file
