@@ -4,7 +4,7 @@ import random
 from ..utils import Board
 from ..utils import edit_board, format_board
 
-class TicTacToe:
+class TicTacToe(commands.Cog):
     """
     Tic Tac Toe command
     """
@@ -103,15 +103,15 @@ class TicTacToe:
                     )
                     if inp.content == "cancel":
                         return await ctx.send("Cancelled the game")
-                    outp = make_move(inp.content, board, "x")
+                    outp = self.make_move(inp.content, board, "x")
                     if outp[0]:
                         board = outp[1]
                     else:
                         await ctx.send(outp[1], delete_after=5)
                         continue
                 else:
-                    board = make_random_move(board)
-                h = has_won(board, 'x' if turn == ctx.author else 'o')
+                    board = self.make_random_move(board)
+                h = self.has_won(board, 'x' if turn == ctx.author else 'o')
                 if h[0]:
                     return await ctx.send(
                         embed=discord.Embed(
@@ -134,51 +134,51 @@ class TicTacToe:
                         color=discord.Color.blurple()
                     )
                 )
-        if member.bot or member == ctx.author:
+        elif member.bot or member == ctx.author:
             return await ctx.send(
                 f"Invalid Syntax: Can't play against {member.display_name}"
             )
-        turn = ctx.author
-        board = Board(3, 3, "|")
-        embed = discord.Embed(
-            title="TicTacToe",
-            description=f"turn: `{turn.display_name}`\n```{format_board(board)}\n```",
-            color=discord.Color.blurple()
-        )
-        msg = await ctx.send(embed=embed)
-        while True:
-            inp = await ctx.bot.wait_for(
-                "message",
-                check=lambda m: m.author == turn and m.channel == ctx.channel,
+            turn = ctx.author
+            board = Board(3, 3, "|")
+            embed = discord.Embed(
+                title="TicTacToe",
+                description=f"turn: `{turn.display_name}`\n```{format_board(board)}\n```",
+                color=discord.Color.blurple()
             )
-            if inp.content == "cancel":
-                return await ctx.send("Cancelled the game")
-            outp = self.make_move(
-                inp.content, board, "x" if turn == ctx.author else "o"
-            )
-            if outp[0]:
-                board = outp[1]
-            else:
-                await ctx.send(outp[1])
-                continue
-            h = self.has_won(board, "x" if turn == ctx.author else "o")
-            if h[0]:
-                return await ctx.send(
+            msg = await ctx.send(embed=embed)
+            while True:
+                inp = await ctx.bot.wait_for(
+                    "message",
+                    check=lambda m: m.author == turn and m.channel == ctx.channel,
+                )
+                if inp.content == "cancel":
+                    return await ctx.send("Cancelled the game")
+                outp = self.make_move(
+                    inp.content, board, "x" if turn == ctx.author else "o"
+                )
+                if outp[0]:
+                    board = outp[1]
+                else:
+                    await ctx.send(outp[1])
+                    continue
+                h = self.has_won(board, "x" if turn == ctx.author else "o")
+                if h[0]:
+                    return await ctx.send(
+                        embed=discord.Embed(
+                            title="TicTacToe",
+                            description=(
+                                "winner: `"
+                                f"{'tie' if h[1] == 'tie' else (ctx.author.display_name if h[1] == 'x' else member.display_name)}`"
+                                "\n"
+                                f"```{format_board(board)}```"
+                                "\n"
+                            ),
+                        )
+                    )
+                turn = member if turn == ctx.author else ctx.author
+                await msg.edit(
                     embed=discord.Embed(
                         title="TicTacToe",
-                        description=(
-                            "winner: `"
-                            f"{'tie' if h[1] == 'tie' else (ctx.author.display_name if h[1] == 'x' else member.display_name)}`"
-                            "\n"
-                            f"```{format_board(board)}```"
-                            "\n"
-                        ),
+                        description=f"turn: `{turn.display_name}`\n```{format_board(board)}\n```",
                     )
                 )
-            turn = member if turn == ctx.author else ctx.author
-            await msg.edit(
-                embed=discord.Embed(
-                    title="TicTacToe",
-                    description=f"turn: `{turn.display_name}`\n```{format_board(board)}\n```",
-                )
-            )
\ No newline at end of file
